# rest
Cyberwave platform REST API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.17.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import rest
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import rest
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import rest
from rest.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = rest.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: CustomTokenAuthentication
configuration.api_key['CustomTokenAuthentication'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['CustomTokenAuthentication'] = 'Bearer'


# Enter a context with an instance of the API client
with rest.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = rest.DefaultApi(api_client)
    uuid = 'uuid_example' # str | 
    complete_large_upload_schema = rest.CompleteLargeUploadSchema() # CompleteLargeUploadSchema | 

    try:
        # Complete Large Glb Upload
        api_response = api_instance.src_app_api_assets_complete_large_glb_upload(uuid, complete_large_upload_schema)
        print("The response of DefaultApi->src_app_api_assets_complete_large_glb_upload:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->src_app_api_assets_complete_large_glb_upload: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**src_app_api_assets_complete_large_glb_upload**](docs/DefaultApi.md#src_app_api_assets_complete_large_glb_upload) | **POST** /api/v1/assets/{uuid}/complete-large-glb-upload | Complete Large Glb Upload
*DefaultApi* | [**src_app_api_assets_create_asset**](docs/DefaultApi.md#src_app_api_assets_create_asset) | **POST** /api/v1/assets | Create Asset
*DefaultApi* | [**src_app_api_assets_create_asset_with_urdf**](docs/DefaultApi.md#src_app_api_assets_create_asset_with_urdf) | **POST** /api/v1/assets/create-with-urdf | Create Asset With Urdf
*DefaultApi* | [**src_app_api_assets_delete_asset**](docs/DefaultApi.md#src_app_api_assets_delete_asset) | **DELETE** /api/v1/assets/{uuid} | Delete Asset
*DefaultApi* | [**src_app_api_assets_get_asset**](docs/DefaultApi.md#src_app_api_assets_get_asset) | **GET** /api/v1/assets/{uuid} | Get Asset
*DefaultApi* | [**src_app_api_assets_get_asset_kinematics**](docs/DefaultApi.md#src_app_api_assets_get_asset_kinematics) | **GET** /api/v1/assets/{uuid}/kinematics | Get Asset Kinematics
*DefaultApi* | [**src_app_api_assets_get_popular_tags**](docs/DefaultApi.md#src_app_api_assets_get_popular_tags) | **GET** /api/v1/assets/popular-tags | Get Popular Tags
*DefaultApi* | [**src_app_api_assets_initiate_large_glb_upload**](docs/DefaultApi.md#src_app_api_assets_initiate_large_glb_upload) | **POST** /api/v1/assets/{uuid}/initiate-large-glb-upload | Initiate Large Glb Upload
*DefaultApi* | [**src_app_api_assets_list_assets**](docs/DefaultApi.md#src_app_api_assets_list_assets) | **GET** /api/v1/assets | List Assets
*DefaultApi* | [**src_app_api_assets_llm_generation**](docs/DefaultApi.md#src_app_api_assets_llm_generation) | **POST** /api/v1/assets/{uuid}/llm-generation | Llm Generation
*DefaultApi* | [**src_app_api_assets_set_glb_from_attachment**](docs/DefaultApi.md#src_app_api_assets_set_glb_from_attachment) | **POST** /api/v1/assets/{uuid}/glb-from-attachment | Set Glb From Attachment
*DefaultApi* | [**src_app_api_assets_update_asset**](docs/DefaultApi.md#src_app_api_assets_update_asset) | **PUT** /api/v1/assets/{uuid} | Update Asset
*DefaultApi* | [**src_app_api_assets_upload_glb**](docs/DefaultApi.md#src_app_api_assets_upload_glb) | **POST** /api/v1/assets/{uuid}/glb-file | Upload Glb
*DefaultApi* | [**src_app_api_assets_upload_thumbnail_file**](docs/DefaultApi.md#src_app_api_assets_upload_thumbnail_file) | **POST** /api/v1/assets/{uuid}/thumbnail-file | Upload Thumbnail File
*DefaultApi* | [**src_app_api_attachments_complete_large_attachment_upload**](docs/DefaultApi.md#src_app_api_attachments_complete_large_attachment_upload) | **POST** /api/v1/attachments/{uuid}/complete-large-upload | Complete Large Attachment Upload
*DefaultApi* | [**src_app_api_attachments_create_attachment**](docs/DefaultApi.md#src_app_api_attachments_create_attachment) | **POST** /api/v1/attachments | Create Attachment
*DefaultApi* | [**src_app_api_attachments_delete_attachment**](docs/DefaultApi.md#src_app_api_attachments_delete_attachment) | **DELETE** /api/v1/attachments/{uuid} | Delete Attachment
*DefaultApi* | [**src_app_api_attachments_get_attachment**](docs/DefaultApi.md#src_app_api_attachments_get_attachment) | **GET** /api/v1/attachments/{uuid} | Get Attachment
*DefaultApi* | [**src_app_api_attachments_initiate_large_attachment_upload**](docs/DefaultApi.md#src_app_api_attachments_initiate_large_attachment_upload) | **POST** /api/v1/attachments/{uuid}/initiate-large-upload | Initiate Large Attachment Upload
*DefaultApi* | [**src_app_api_attachments_list_attachments**](docs/DefaultApi.md#src_app_api_attachments_list_attachments) | **GET** /api/v1/attachments | List Attachments
*DefaultApi* | [**src_app_api_attachments_update_attachment**](docs/DefaultApi.md#src_app_api_attachments_update_attachment) | **PUT** /api/v1/attachments/{uuid} | Update Attachment
*DefaultApi* | [**src_app_api_attachments_upload_attachment**](docs/DefaultApi.md#src_app_api_attachments_upload_attachment) | **POST** /api/v1/attachments/{uuid}/upload | Upload Attachment
*DefaultApi* | [**src_app_api_contact_contact_form**](docs/DefaultApi.md#src_app_api_contact_contact_form) | **POST** /api/v1/contact/ | Contact Form
*DefaultApi* | [**src_app_api_environments_cancel_environment_invitation**](docs/DefaultApi.md#src_app_api_environments_cancel_environment_invitation) | **DELETE** /api/v1/environments/invitations/{invitation_uuid} | Cancel Environment Invitation
*DefaultApi* | [**src_app_api_environments_create_environment_for_project**](docs/DefaultApi.md#src_app_api_environments_create_environment_for_project) | **POST** /api/v1/projects/{project_uuid}/environments | Create Environment For Project
*DefaultApi* | [**src_app_api_environments_create_environment_link**](docs/DefaultApi.md#src_app_api_environments_create_environment_link) | **POST** /api/v1/environments/{uuid}/create-link | Create Environment Link
*DefaultApi* | [**src_app_api_environments_create_environment_simulation**](docs/DefaultApi.md#src_app_api_environments_create_environment_simulation) | **POST** /api/v1/environments/{uuid}/simulations | Create Environment Simulation
*DefaultApi* | [**src_app_api_environments_create_standalone_environment**](docs/DefaultApi.md#src_app_api_environments_create_standalone_environment) | **POST** /api/v1/environments | Create Standalone Environment
*DefaultApi* | [**src_app_api_environments_delete_environment_for_project**](docs/DefaultApi.md#src_app_api_environments_delete_environment_for_project) | **DELETE** /api/v1/projects/{project_uuid}/environments/{uuid} | Delete Environment For Project
*DefaultApi* | [**src_app_api_environments_get_environment**](docs/DefaultApi.md#src_app_api_environments_get_environment) | **GET** /api/v1/environments/{uuid} | Get Environment
*DefaultApi* | [**src_app_api_environments_get_environment_invitations**](docs/DefaultApi.md#src_app_api_environments_get_environment_invitations) | **GET** /api/v1/environments/{uuid}/invitations | Get Environment Invitations
*DefaultApi* | [**src_app_api_environments_get_environment_mujoco_scene**](docs/DefaultApi.md#src_app_api_environments_get_environment_mujoco_scene) | **GET** /api/v1/environments/{uuid}/mujoco-scene.xml | Get Environment Mujoco Scene
*DefaultApi* | [**src_app_api_environments_get_environment_sharing_info_endpoint**](docs/DefaultApi.md#src_app_api_environments_get_environment_sharing_info_endpoint) | **GET** /api/v1/environments/{uuid}/sharing | Get Environment Sharing Info Endpoint
*DefaultApi* | [**src_app_api_environments_get_environment_simulations**](docs/DefaultApi.md#src_app_api_environments_get_environment_simulations) | **GET** /api/v1/environments/{uuid}/simulations | Get Environment Simulations
*DefaultApi* | [**src_app_api_environments_get_environment_twins**](docs/DefaultApi.md#src_app_api_environments_get_environment_twins) | **GET** /api/v1/environments/{uuid}/twins | Get Environment Twins
*DefaultApi* | [**src_app_api_environments_invite_user_to_environment**](docs/DefaultApi.md#src_app_api_environments_invite_user_to_environment) | **POST** /api/v1/environments/{uuid}/invite | Invite User To Environment
*DefaultApi* | [**src_app_api_environments_list_all_environments**](docs/DefaultApi.md#src_app_api_environments_list_all_environments) | **GET** /api/v1/environments | List All Environments
*DefaultApi* | [**src_app_api_environments_list_environments_for_project**](docs/DefaultApi.md#src_app_api_environments_list_environments_for_project) | **GET** /api/v1/projects/{project_uuid}/environments | List Environments For Project
*DefaultApi* | [**src_app_api_environments_remove_user_from_environment**](docs/DefaultApi.md#src_app_api_environments_remove_user_from_environment) | **DELETE** /api/v1/environments/{uuid}/users/{user_id} | Remove User From Environment
*DefaultApi* | [**src_app_api_environments_reset_environment**](docs/DefaultApi.md#src_app_api_environments_reset_environment) | **POST** /api/v1/environments/{uuid}/reset | Reset Environment
*DefaultApi* | [**src_app_api_environments_revoke_environment_link**](docs/DefaultApi.md#src_app_api_environments_revoke_environment_link) | **POST** /api/v1/environments/{uuid}/revoke-link | Revoke Environment Link
*DefaultApi* | [**src_app_api_environments_share_environment_with_user**](docs/DefaultApi.md#src_app_api_environments_share_environment_with_user) | **POST** /api/v1/environments/{uuid}/share | Share Environment With User
*DefaultApi* | [**src_app_api_environments_stop_environment_simulation**](docs/DefaultApi.md#src_app_api_environments_stop_environment_simulation) | **POST** /api/v1/environments/{uuid}/simulations/{simulation_id}/stop | Stop Environment Simulation
*DefaultApi* | [**src_app_api_environments_update_environment_for_project**](docs/DefaultApi.md#src_app_api_environments_update_environment_for_project) | **PUT** /api/v1/projects/{project_uuid}/environments/{uuid} | Update Environment For Project
*DefaultApi* | [**src_app_api_invitation_router_accept_invitation_endpoint**](docs/DefaultApi.md#src_app_api_invitation_router_accept_invitation_endpoint) | **GET** /api/v1/invitations/accept/{token} | Accept Invitation Endpoint
*DefaultApi* | [**src_app_api_invitation_router_get_invitation_info**](docs/DefaultApi.md#src_app_api_invitation_router_get_invitation_info) | **GET** /api/v1/invitations/info/{token} | Get Invitation Info
*DefaultApi* | [**src_app_api_projects_create_project**](docs/DefaultApi.md#src_app_api_projects_create_project) | **POST** /api/v1/projects | Create Project
*DefaultApi* | [**src_app_api_projects_create_project_link**](docs/DefaultApi.md#src_app_api_projects_create_project_link) | **POST** /api/v1/projects/{uuid}/create-link | Create Project Link
*DefaultApi* | [**src_app_api_projects_delete_project**](docs/DefaultApi.md#src_app_api_projects_delete_project) | **DELETE** /api/v1/projects/{uuid} | Delete Project
*DefaultApi* | [**src_app_api_projects_get_my_project_permissions**](docs/DefaultApi.md#src_app_api_projects_get_my_project_permissions) | **GET** /api/v1/projects/{uuid}/my-permissions | Get My Project Permissions
*DefaultApi* | [**src_app_api_projects_get_project**](docs/DefaultApi.md#src_app_api_projects_get_project) | **GET** /api/v1/projects/{uuid} | Get Project
*DefaultApi* | [**src_app_api_projects_get_project_shares**](docs/DefaultApi.md#src_app_api_projects_get_project_shares) | **GET** /api/v1/projects/{uuid}/shares | Get Project Shares
*DefaultApi* | [**src_app_api_projects_list_projects**](docs/DefaultApi.md#src_app_api_projects_list_projects) | **GET** /api/v1/projects | List Projects
*DefaultApi* | [**src_app_api_projects_revoke_project_link**](docs/DefaultApi.md#src_app_api_projects_revoke_project_link) | **POST** /api/v1/projects/{uuid}/revoke-link | Revoke Project Link
*DefaultApi* | [**src_app_api_projects_share_project**](docs/DefaultApi.md#src_app_api_projects_share_project) | **POST** /api/v1/projects/{uuid}/share | Share Project
*DefaultApi* | [**src_app_api_projects_unshare_project**](docs/DefaultApi.md#src_app_api_projects_unshare_project) | **POST** /api/v1/projects/{uuid}/unshare | Unshare Project
*DefaultApi* | [**src_app_api_projects_update_project**](docs/DefaultApi.md#src_app_api_projects_update_project) | **PUT** /api/v1/projects/{uuid} | Update Project
*DefaultApi* | [**src_app_api_twins_create_twin**](docs/DefaultApi.md#src_app_api_twins_create_twin) | **POST** /api/v1/twins | Create Twin
*DefaultApi* | [**src_app_api_twins_delete_twin**](docs/DefaultApi.md#src_app_api_twins_delete_twin) | **DELETE** /api/v1/twins/{uuid} | Delete Twin
*DefaultApi* | [**src_app_api_twins_get_actuation_data**](docs/DefaultApi.md#src_app_api_twins_get_actuation_data) | **GET** /api/v1/twins/{uuid}/telemetry | Get Actuation Data
*DefaultApi* | [**src_app_api_twins_get_twin**](docs/DefaultApi.md#src_app_api_twins_get_twin) | **GET** /api/v1/twins/{uuid} | Get Twin
*DefaultApi* | [**src_app_api_twins_get_twin_relationships**](docs/DefaultApi.md#src_app_api_twins_get_twin_relationships) | **GET** /api/v1/twins/{uuid}/relationships | Get Twin Relationships
*DefaultApi* | [**src_app_api_twins_list_all_twins**](docs/DefaultApi.md#src_app_api_twins_list_all_twins) | **GET** /api/v1/twins | List All Twins
*DefaultApi* | [**src_app_api_twins_save_actuation_data**](docs/DefaultApi.md#src_app_api_twins_save_actuation_data) | **POST** /api/v1/twins/{uuid}/telemetry | Save Actuation Data
*DefaultApi* | [**src_app_api_twins_update_twin**](docs/DefaultApi.md#src_app_api_twins_update_twin) | **PUT** /api/v1/twins/{uuid} | Update Twin
*DefaultApi* | [**src_app_api_twins_update_twin_state**](docs/DefaultApi.md#src_app_api_twins_update_twin_state) | **PATCH** /api/v1/twins/{identifier}/state | Update Twin State
*DefaultApi* | [**src_app_api_urdf_create_urdf_project**](docs/DefaultApi.md#src_app_api_urdf_create_urdf_project) | **POST** /api/v1/urdf-projects | Create Urdf Project
*DefaultApi* | [**src_app_api_urdf_delete_urdf_project**](docs/DefaultApi.md#src_app_api_urdf_delete_urdf_project) | **DELETE** /api/v1/urdf-projects/{uuid} | Delete Urdf Project
*DefaultApi* | [**src_app_api_urdf_get_twin_joint_state**](docs/DefaultApi.md#src_app_api_urdf_get_twin_joint_state) | **GET** /api/v1/twins/{uuid}/joints/{joint_name}/state | Get Twin Joint State
*DefaultApi* | [**src_app_api_urdf_get_twin_joint_states**](docs/DefaultApi.md#src_app_api_urdf_get_twin_joint_states) | **GET** /api/v1/twins/{uuid}/joint_states | Get Twin Joint States
*DefaultApi* | [**src_app_api_urdf_get_twin_joints**](docs/DefaultApi.md#src_app_api_urdf_get_twin_joints) | **GET** /api/v1/twins/{uuid}/joints | Get Twin Joints
*DefaultApi* | [**src_app_api_urdf_get_twin_robot_description**](docs/DefaultApi.md#src_app_api_urdf_get_twin_robot_description) | **GET** /api/v1/twins/{uuid}/robot_description | Get Twin Robot Description
*DefaultApi* | [**src_app_api_urdf_get_twin_urdf_raw**](docs/DefaultApi.md#src_app_api_urdf_get_twin_urdf_raw) | **GET** /api/v1/twins/{uuid}/urdf | Get Twin Urdf Raw
*DefaultApi* | [**src_app_api_urdf_get_urdf_project**](docs/DefaultApi.md#src_app_api_urdf_get_urdf_project) | **GET** /api/v1/urdf-projects/{uuid} | Get Urdf Project
*DefaultApi* | [**src_app_api_urdf_list_urdf_projects**](docs/DefaultApi.md#src_app_api_urdf_list_urdf_projects) | **GET** /api/v1/urdf-projects | List Urdf Projects
*DefaultApi* | [**src_app_api_urdf_update_twin_joint_state**](docs/DefaultApi.md#src_app_api_urdf_update_twin_joint_state) | **PUT** /api/v1/twins/{uuid}/joints/{joint_name}/state | Update Twin Joint State
*DefaultApi* | [**src_app_api_urdf_update_twin_joint_states**](docs/DefaultApi.md#src_app_api_urdf_update_twin_joint_states) | **PUT** /api/v1/twins/{uuid}/joint_states | Update Twin Joint States
*DefaultApi* | [**src_app_api_urdf_update_urdf_project**](docs/DefaultApi.md#src_app_api_urdf_update_urdf_project) | **PUT** /api/v1/urdf-projects/{uuid} | Update Urdf Project
*DefaultApi* | [**src_app_api_urdf_upload_zip_file**](docs/DefaultApi.md#src_app_api_urdf_upload_zip_file) | **POST** /api/v1/urdf-projects/{uuid}/zip-file | Upload Zip File
*DefaultApi* | [**src_users_api_members_leave_team**](docs/DefaultApi.md#src_users_api_members_leave_team) | **DELETE** /api/v1users/workspaces/{team_uuid}/members/{uuid}/leave | Leave Team
*DefaultApi* | [**src_users_api_members_list_team_members**](docs/DefaultApi.md#src_users_api_members_list_team_members) | **GET** /api/v1users/workspaces/{team_uuid}/members | List Team Members
*DefaultApi* | [**src_users_api_members_remove_team_member**](docs/DefaultApi.md#src_users_api_members_remove_team_member) | **DELETE** /api/v1users/workspaces/{team_uuid}/members/{uuid} | Remove Team Member
*DefaultApi* | [**src_users_api_organizations_delete_organization**](docs/DefaultApi.md#src_users_api_organizations_delete_organization) | **DELETE** /api/v1users/organizations/{uuid} | Delete Organization
*DefaultApi* | [**src_users_api_organizations_get_organization**](docs/DefaultApi.md#src_users_api_organizations_get_organization) | **GET** /api/v1users/organizations/{uuid} | Get Organization
*DefaultApi* | [**src_users_api_organizations_get_organization_by_slug**](docs/DefaultApi.md#src_users_api_organizations_get_organization_by_slug) | **GET** /api/v1users/organizations/by-slug/{slug} | Get Organization By Slug
*DefaultApi* | [**src_users_api_organizations_list_organizations**](docs/DefaultApi.md#src_users_api_organizations_list_organizations) | **GET** /api/v1users/organizations | List Organizations
*DefaultApi* | [**src_users_api_organizations_update_organization**](docs/DefaultApi.md#src_users_api_organizations_update_organization) | **PUT** /api/v1users/organizations/{uuid} | Update Organization
*DefaultApi* | [**src_users_api_plans_get_plan**](docs/DefaultApi.md#src_users_api_plans_get_plan) | **GET** /api/v1users/plan | Get Plan
*DefaultApi* | [**src_users_api_workspaces_create_workspace**](docs/DefaultApi.md#src_users_api_workspaces_create_workspace) | **POST** /api/v1users/workspaces | Create Workspace
*DefaultApi* | [**src_users_api_workspaces_delete_workspace**](docs/DefaultApi.md#src_users_api_workspaces_delete_workspace) | **DELETE** /api/v1users/workspaces/{uuid} | Delete Workspace
*DefaultApi* | [**src_users_api_workspaces_get_default_workspace**](docs/DefaultApi.md#src_users_api_workspaces_get_default_workspace) | **GET** /api/v1users/workspaces/default | Get Default Workspace
*DefaultApi* | [**src_users_api_workspaces_get_workspace**](docs/DefaultApi.md#src_users_api_workspaces_get_workspace) | **GET** /api/v1users/workspaces/{uuid} | Get Workspace
*DefaultApi* | [**src_users_api_workspaces_list_workspaces**](docs/DefaultApi.md#src_users_api_workspaces_list_workspaces) | **GET** /api/v1users/workspace | List Workspaces
*DefaultApi* | [**src_users_api_workspaces_set_default_workspace**](docs/DefaultApi.md#src_users_api_workspaces_set_default_workspace) | **POST** /api/v1users/workspaces/default | Set Default Workspace
*DefaultApi* | [**src_users_api_workspaces_update_workspace**](docs/DefaultApi.md#src_users_api_workspaces_update_workspace) | **PUT** /api/v1users/workspaces/{uuid} | Update Workspace


## Documentation For Models

 - [AssetCreateSchema](docs/AssetCreateSchema.md)
 - [AssetCreateWithURDFSchema](docs/AssetCreateWithURDFSchema.md)
 - [AssetGLBFromAttachmentSchema](docs/AssetGLBFromAttachmentSchema.md)
 - [AssetSchema](docs/AssetSchema.md)
 - [AssetUpdateSchema](docs/AssetUpdateSchema.md)
 - [AttachmentCreateSchema](docs/AttachmentCreateSchema.md)
 - [AttachmentSchema](docs/AttachmentSchema.md)
 - [BulkJointStatesUpdateSchema](docs/BulkJointStatesUpdateSchema.md)
 - [CompleteLargeUploadSchema](docs/CompleteLargeUploadSchema.md)
 - [ContactFormSchema](docs/ContactFormSchema.md)
 - [EnvironmentCreateSchema](docs/EnvironmentCreateSchema.md)
 - [EnvironmentSchema](docs/EnvironmentSchema.md)
 - [InitiateLargeUploadResponse](docs/InitiateLargeUploadResponse.md)
 - [InitiateLargeUploadSchema](docs/InitiateLargeUploadSchema.md)
 - [JointSchema](docs/JointSchema.md)
 - [JointStateSchema](docs/JointStateSchema.md)
 - [JointStateUpdateSchema](docs/JointStateUpdateSchema.md)
 - [JointStatesSchema](docs/JointStatesSchema.md)
 - [LLMGenerationSchema](docs/LLMGenerationSchema.md)
 - [LLMResponseSchema](docs/LLMResponseSchema.md)
 - [LinkShareCreateSchema](docs/LinkShareCreateSchema.md)
 - [LinkShareRevokeSchema](docs/LinkShareRevokeSchema.md)
 - [LinkShareSchema](docs/LinkShareSchema.md)
 - [OrganizationSchema](docs/OrganizationSchema.md)
 - [OrganizationUpdateSchema](docs/OrganizationUpdateSchema.md)
 - [PermissionsSchema](docs/PermissionsSchema.md)
 - [PlanSchema](docs/PlanSchema.md)
 - [PopularTagSchema](docs/PopularTagSchema.md)
 - [PopularTagsResponseSchema](docs/PopularTagsResponseSchema.md)
 - [ProjectCreateSchema](docs/ProjectCreateSchema.md)
 - [ProjectSchema](docs/ProjectSchema.md)
 - [PublicUserSchema](docs/PublicUserSchema.md)
 - [RobotDescriptionSchema](docs/RobotDescriptionSchema.md)
 - [ShareSchema](docs/ShareSchema.md)
 - [SharesResponseSchema](docs/SharesResponseSchema.md)
 - [TeamMemberResponse](docs/TeamMemberResponse.md)
 - [TeamShareSchema](docs/TeamShareSchema.md)
 - [TwinCreateSchema](docs/TwinCreateSchema.md)
 - [TwinRelationshipSchema](docs/TwinRelationshipSchema.md)
 - [TwinSchema](docs/TwinSchema.md)
 - [TwinStateUpdateSchema](docs/TwinStateUpdateSchema.md)
 - [TwinTelemetrySchema](docs/TwinTelemetrySchema.md)
 - [URDFProjectCreateSchema](docs/URDFProjectCreateSchema.md)
 - [URDFProjectSchema](docs/URDFProjectSchema.md)
 - [UserSchema](docs/UserSchema.md)
 - [UserShareSchema](docs/UserShareSchema.md)
 - [WorkspaceResponseSchema](docs/WorkspaceResponseSchema.md)
 - [WorkspaceSchema](docs/WorkspaceSchema.md)
 - [WorkspaceUpdateSchema](docs/WorkspaceUpdateSchema.md)
 - [WorkspaceUserSchema](docs/WorkspaceUserSchema.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="CustomTokenAuthentication"></a>
### CustomTokenAuthentication

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




